@@ -79,15 +79,15 @@ kiriki::kiriki() : KXmlGuiWindow(), m_hintGiven(false)
 	connect(m_scoresWidget, &QTreeView::pressed, this, &kiriki::pressed);
 	lay -> addWidget(m_scoresWidget, 1);
 	
-	m_scores = 0;
+	m_scores = nullptr;
 	
 	// Game
-	QAction *gameNewAction = KStandardGameAction::gameNew(this, SLOT(newGame()), actionCollection());
-	KStandardGameAction::highscores(this, SLOT(showHighScores()), actionCollection());
-	KStandardGameAction::print(this, SLOT(print()), actionCollection());
-	KStandardGameAction::quit(qApp, SLOT(quit()), actionCollection());
-	m_hintAction = KStandardGameAction::hint(this, SLOT(showHint()), actionCollection());
-	m_demoAction = KStandardGameAction::demo(this, SLOT(demo()), actionCollection());
+	QAction *gameNewAction = KStandardGameAction::gameNew(this, &kiriki::newGame, actionCollection());
+	KStandardGameAction::highscores(this, &kiriki::showHighScores, actionCollection());
+	KStandardGameAction::print(this, &kiriki::print, actionCollection());
+	KStandardGameAction::quit(qApp, &QApplication::quit, actionCollection());
+	m_hintAction = KStandardGameAction::hint(this, &kiriki::showHint, actionCollection());
+	m_demoAction = KStandardGameAction::demo(this, &kiriki::demo, actionCollection());
 	connect(gameNewAction, &QAction::triggered, m_demoAction, &KToggleAction::setChecked);
 	connect(gameNewAction, &QAction::triggered, m_demoAction, &KToggleAction::setDisabled);
 	connect(gameNewAction, &QAction::triggered, m_hintAction, &QAction::setDisabled);
@@ -100,7 +100,7 @@ kiriki::kiriki() : KXmlGuiWindow(), m_hintGiven(false)
 	connect(m_lateral, &lateralWidget::newGameClicked, gameNewAction, &QAction::trigger);
 	
 	// Preferences
-	KStandardAction::preferences(this, SLOT(showPreferences()), actionCollection());
+	KStandardAction::preferences(this, &kiriki::showPreferences, actionCollection());
 	
 	setCentralWidget(w);
 	setupGUI(Keys | Save | Create);
@@ -116,7 +116,7 @@ void kiriki::pressed(const QModelIndex &index)
 
 	if (index.column() == 0 || index.column() == m_scores -> currentPlayerNumber() + 1) play(index);
 
-	m_scoresWidget -> setItemDelegateForRow(m_highlightedRowIndex, 0);
+	m_scoresWidget -> setItemDelegateForRow(m_highlightedRowIndex, nullptr);
 }
 
 void kiriki::play(const QModelIndex &index)
@@ -195,7 +195,7 @@ void kiriki::demo()
 	kirikiSettings::setPlayer6IsHuman(false);
 	kirikiSettings::setNumberOfPlayers(6);
 	newGame();
-	emit demoStarted();
+	Q_EMIT demoStarted();
 	disconnect(m_lateral, &lateralWidget::rolled, statusBar(), &QWidget::hide);
 	kirikiSettings::setPlayer1IsHuman(preDemoHumans[0]);
 	kirikiSettings::setPlayer2IsHuman(preDemoHumans[1]);
@@ -405,4 +405,4 @@ void kiriki::playComputer()
 	else m_lateral -> setEnabled(true);
 }
 
-
+#include "moc_kiriki.cpp"
